@@ -25,6 +25,13 @@ _m = []
 
 def parens(expr):
     """
+    >>> from nl.arith import parens
+    >>> parens('uno')
+    'uno'
+    >>> parens('(uno (dos tres) cuatro)')
+    ['uno', '(dos tres)', 'cuatro']
+    >>> parens('(uno (dos tres) (ho ho (he (ha ha))) cuatro)')
+    ['uno', '(dos tres)', '(ho ho (he (ha ha)))', 'cuatro']
     """
     if expr[0] != '(':
         return expr
@@ -135,14 +142,4 @@ class Arith(Number):
         arg2 = self.arg2.put(vrs)
         return '(test (%s %s %s))' % (self.value, arg1, arg2)
 
-    def get_isc(self, templs, queries, vrs):
-        arg1 =  self.arg1.put(vrs)
-        arg2 =  self.arg2.put(vrs)
-        queries.append('(%s %s %s)' % (self.value, arg1, arg2))
-
-    def __str__(self):
-        queries = []
-        self.get_isc([], queries)
-        return queries.pop()
-
 register('Arith', Arith)
