@@ -5,7 +5,7 @@ from nl.log import logger
 
 #clips.DebugConfig.ExternalTraceback = True
 #clips.EngineConfig.ResetGlobals = True
-#clips.EngineConfig.IncrementalReset = True
+clips.EngineConfig.IncrementalReset = True
 
 
 # CLIPS SNIPPETS
