@@ -26,15 +26,7 @@ class cms_test(object):
         reset()
         del self.cms
 
-#    def thing_test(self):
-#        pooh = self.cms.Person('pooh')
-#        assert repr(pooh) == 'pooh is a Person'
-#        assert str(pooh) == 'pooh'
-
-
     def third_test(self):
-        #from nl.examples import cms2
-        #self.cms = cms2
         # john is a person
         john = self.cms.Person('john')
         # pete is a person
@@ -77,6 +69,9 @@ class cms_test(object):
         assert not nl.kb.ask(nl.Fact(c2, self.cms.Has(what=self.cms.public), self.cms.Duration(start=self.cms.Instant('now'))))
         # to the question can jane view c1?, the answer is yes
         assert nl.kb.ask(nl.Fact(jane, self.cms.Can(what=self.cms.View(what=c1)), self.cms.Duration(start=self.cms.Instant('now'))))
+        assert nl.kb.ask(nl.Fact(jane, self.cms.Can(what=self.cms.View('X1')), self.cms.Duration(start=self.cms.Instant('now'))))
+        assert nl.kb.ask(nl.Fact(self.cms.admin, self.cms.Can(what=self.cms.Publish(what='X1')), self.cms.Duration(start=self.cms.Instant('now'))))
+        assert len(nl.kb.ask(nl.Fact(self.cms.admin, self.cms.Can('X1'), self.cms.Duration(start=self.cms.Instant('now'))), nl.Fact(jane, self.cms.Can('X1'), self.cms.Duration(start=self.cms.Instant('now'))))) == 1
         # to the question can pete view c1?, the answer is no
         assert not nl.kb.ask(nl.Fact(pete, self.cms.Can(what=self.cms.View(what=c1)), self.cms.Duration(start=self.cms.Instant('now'))))
         # john wants to publish c1
@@ -103,12 +98,25 @@ class cms_test(object):
         # who can view what?
         assert nl.kb.ask(self.cms.Content('X1'), self.cms.Person('X2'), nl.Fact(self.cms.Person('X2'), self.cms.Can(what=self.cms.View(what='X1')), nl.Duration(start=nl.Instant('now')))) == [{'X2': 'admin', 'X1': 'c1'}, {'X2': 'john', 'X1': 'c1'}, {'X2': 'pete', 'X1': 'c1'}, {'X2': 'jane', 'X1': 'c1'}, {'X2': 'admin', 'X1': 'c2'}, {'X2': 'john', 'X1': 'c2'}]
 
-        # what permissions has admin?
-        assert nl.kb.ask(self.cms.Permission('X2'), nl.Fact(self.cms.manager, self.cms.Has(what=self.cms.Permission('X2')), nl.Duration(start=nl.Instant('X3')))) == [{'X2': 'basic_perm'}, {'X2': 'manage_perm'}, {'X2': 'create_perm'}]
+        # who can hide what?
+        assert nl.kb.ask(self.cms.Content('X1'), self.cms.Person('X2'), nl.Fact(self.cms.Person('X2'), self.cms.Can(what=self.cms.Hide(what='X1')), nl.Duration(start=nl.Instant('now')))) == [{'X2': 'admin', 'X1': 'c1'}, {'X2': 'john', 'X1': 'c1'}, {'X2': 'jane', 'X1': 'c1'}]
+
+        # how many permissions has admin?
+        assert len(nl.kb.ask(self.cms.Permission('X2'), nl.Fact(self.cms.admin, self.cms.Has(what=self.cms.Permission('X2')), nl.Duration(start=nl.Instant('X3'))))) == 3
 
         # can admin view c2?
         assert nl.kb.ask(nl.Fact(self.cms.admin, self.cms.Can(what=self.cms.View(what=c2)), nl.Duration(start=nl.Instant('now'))))
 
+        assert nl.kb.ask(nl.Duration('X1'),
+                             nl.Fact(c2,
+                                 self.cms.Has(what=self.cms.private),
+                                 nl.Duration('X1')))
+
+        import os
+        from nl.log import log_dir, log_file
+        os.remove(log_file)
+        os.rmdir(log_dir)
+
 
 class cms3_test(object):
     def setup(self):
@@ -223,3 +231,5 @@ class physics_test(object):
     def first_test(self):
         fact = nl.kb.ask_obj(nl.Fact(self.p.Body('c1'), self.p.HasPosition(x='X2', y='X3'), 50))
         assert str(fact[0]) == 'c1 hasposition y 57.641201061 x -65.0657847679 at 50.0'
+        resp = nl.kb.ask_obj(nl.Fact(self.p.c1, self.p.HasPosition(x='X1', y='X2'), 'X3'))
+        assert len(resp) == 100
