@@ -124,25 +124,14 @@ class Thing(Name):
         else:
             return '[%s]' % self.value
 
-    def put_action(self, vrs):
+    def put_action(self, vrs=None):
         """
         put name in clips as a make-instance action.
         """
+        if vrs is None:
+            vrs = {}
         val = self.put(vrs)
         return '(reduce-class %s %s)' % (val, self.__class__.__name__)
 
-    def remove_action(self, vrs=None):
-        templs = []
-        queries = []
-        self.get_ism(templs, queries, newvar='sen')
-        if len(queries) > 1:
-            q = '(do-for-all-instances (%s) (and %s) (send ?sen delete))' % \
-                       (' '.join(['(?%s %s)' % templ for templ in templs]),
-                                                        ' '.join(queries))
-        else:
-            q = '(do-for-all-instances (%s) %s (send ?sen delete))' % \
-                  (' '.join(['(?%s %s)' % templ for templ in templs]),
-                                                queries and queries[0] or 'TRUE')
-        return q
 
 register('Thing', Thing)
