@@ -35,9 +35,7 @@ class Time(utils.Name):
                 return Instant(str(float(instance)))
             except ValueError:
                 instance = clips.FindInstance(instance)
-        if str(instance.Class.Name) == 'Duration':
-            return Duration.from_clips(instance)
-        return Instant(instance)
+        return Duration.from_clips(instance)
 
 utils.register('Time', Time)
 
@@ -51,11 +49,12 @@ class Instant(Time, Number):
 
     Can be used as the time attribute in a Fact
 
-    >>> Fact(Thing('X1'), State('X2'), Instant('now'))
+    >>> from nl import Fact, Thing, State
+    >>> f = Fact(Thing('X1'), State('X2'), Instant('now'))
 
     or as start or end attributes in a Duration.
 
-    >>> Duration(start=Instant(1), end=Instant(3))
+    >>> d = Duration(start=Instant(1), end=Instant(3))
     '''
 
     def __init__(self, *args, **kwargs):
@@ -68,7 +67,10 @@ class Instant(Time, Number):
         """
         """
         num = self._get_number(vrs)
-        if parent:
+        if parent and (not utils.varpat.match(num[1:]) or \
+                       vrs.has_key(num[1:])):
+            if vrs.has_key(num[1:]) and vrs[num[1:]]:
+                num = utils.clips_instance(*(vrs[num[1:]]))
             queries.append( '''
                (or (and (eq (class ?%(parent)s:time) Duration)
                         (<= (send ?%(parent)s:time get-start) %(self)s)
@@ -192,6 +194,18 @@ class Duration(Time):
                                   end.get_isc(templs, queries, vrs)))
         return '?%s' % newvar
 
+    def get_ism(self,  templs, queries, vrs, newvar='time'):
+        """
+        get instance-set method;
+        return (instance-set templates, instance-set queries)
+        """
+        if utils.varpat.match(self.value):
+            templs.append((self.value, self.__class__.__name__))
+            vrs[self.value] = ()
+        else:
+            templs.append((newvar, self.__class__.__name__))
+            queries.append('(eq ?%s %s)' % (newvar, self.put(vrs)))
+
 utils.register('Duration', Duration)
 
 class Finish(utils.Name):
